###########################################################################
#
# RTFPlug.pm -- plugin for importing Rich Text Format files.
#
# A component of the Greenstone digital library software
# from the New Zealand Digital Library Project at the 
# University of Waikato, New Zealand.
#
# Copyright (C) 2001 New Zealand Digital Library Project
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
###########################################################################

# 12/05/02 Added usage datastructure - John Thompson

package RTFPlug;

use ConvertToPlug;

sub BEGIN {
    @ISA = ('ConvertToPlug');
}

my $arguments = [ { 'name' => "process_exp",
		    'desc' => "A perl regular expression to match against filenames. Matching filenames will be processed by this plugin. Each plugin has its own default process_exp. e.g HTMLPlug defaults to '(?i)\.html?\$' i.e. all documents ending in .htm or .html (case-insensitive).",
		    'type' => "string",
		    'deft' => q^(?i)\.rtf$^,
		    'reqd' => "no" }
		  ];

my $options = { 'name'     => "RTFPlug",
		'desc'     => "Plugin for importing Rich Text Format files.",
		'inherits' => "yes",
		'args'     => $arguments };

sub new {
    my $class = shift (@_);
    my $self = new ConvertToPlug ($class, @_);
    
    # 14-05-02 To allow for proper inheritance of arguments - John Thompson
    my $option_list = $self->{'option_list'};
    push( @{$option_list}, $options );

    return bless $self, $class;
}

sub get_default_process_exp {
    my $self = shift (@_);
    return q^(?i)\.rtf$^;
}
    
sub process {
    my $self = shift (@_);

    my $outhandle = $self->{'outhandle'};
    print $outhandle "RTFPlug: passing $_[3] on to $self->{'converted_to'}Plug\n" 
	if $self->{'verbosity'} > 1;

    return ConvertToPlug::process_type($self,"rtf",@_);
}

1;
